@@ -30,6 +30,8 @@
 #include "PopMap.h"
 #include "PopSum.h"
 #include "ordered.h" // for "snp"
+#include "mapping_utils.h"
+#include "genotype_dictionaries.h"
 
 void tally_complete_haplotypes(
         Datum const*const* data,
@@ -105,15 +107,15 @@ class MarkersExport: public Export {
     int  write_batch(const vector<LocBin *> &);
 };
 
-class GenotypesExport: public Export {
+class RawHaplotypesExport: public Export {
     //
     // Output a list of heterozygous loci and the associated haplotype frequencies.
     //
     const MetaPopInfo *_mpopi;
 
  public:
-    GenotypesExport() : _mpopi(NULL) {}
-    ~GenotypesExport() {}
+    RawHaplotypesExport() : _mpopi(NULL) {}
+    ~RawHaplotypesExport() {}
     int  open(const MetaPopInfo *mpopi);
     int  write_header();
     int  write_batch(const vector<LocBin *> &);
@@ -443,18 +445,110 @@ class TreemixExport: public OrderableExport {
     int write_site(const CSLocus* cloc, const LocPopSum* psum, Datum const*const* datums, size_t col, size_t index);
 };
 
+class JoinMapExport: public Export {
+    const MetaPopInfo*_mpopi;
+    const MappingGenotypesProcessor *_gproc;
+    size_t _progeny_index;
+
+    string   _tmp_path;
+    ofstream _tmpfh;
+    ifstream _intmpfh;
+    
+    map<string, string>              _marker_map;
+    map<string, map<string, string>> _genotype_map;
+
+public:
+    JoinMapExport(MappingGenotypesProcessor *g) : _mpopi(NULL), _gproc(g) {}
+    JoinMapExport() : _mpopi(NULL), _gproc(NULL) {}
+    int    open(const MetaPopInfo *mpopi);
+    int    write_batch(const vector<LocBin*>& loci);
+    int    write_header() { return 0; }
+    int    post_processing();
+    void   close();
+};
+
+class OneMapExport: public Export {
+    const MetaPopInfo*_mpopi;
+    const MappingGenotypesProcessor *_gproc;
+    size_t _progeny_index;
+
+    string   _tmp_path;
+    ofstream _tmpfh;
+    ifstream _intmpfh;
+
+    map<string, string> _onemap_marker_types =
+        {{"abxoo", "D1.11"},
+         {"ooxab", "D2.16"},
+         {"abxaa", "D1.10"},
+         {"aaxab", "D2.15"},
+         {"abxab", "B3.7"},
+         {"abxac", "A.2"},
+         {"abxcd", "A.1"}};
+
+    map<string, string>              _marker_map;
+    map<string, map<string, string>> _genotype_map;
+
+ public:
+    OneMapExport(MappingGenotypesProcessor *g) : _mpopi(NULL), _gproc(g) {}
+    OneMapExport() : _mpopi(NULL) {}
+    int    open(const MetaPopInfo *mpopi);
+    int    write_batch(const vector<LocBin*>& loci);
+    int    write_header() { return 0; }
+    int    post_processing();
+    void   close();
+};
+
+class rQTLExport: public Export {
+    const MetaPopInfo*_mpopi;
+    const MappingGenotypesProcessor *_gproc;
+    size_t _progeny_index;
+
+    string   _tmp_path;
+    ofstream _tmpfh;
+    ifstream _intmpfh;
+
+    map<string, string>              _marker_map;
+    map<string, map<string, string>> _genotype_map;
+
+ public:
+    rQTLExport(MappingGenotypesProcessor *g) : _mpopi(NULL), _gproc(g) {}
+    rQTLExport() : _mpopi(NULL) {}
+    int    open(const MetaPopInfo *mpopi);
+    int    write_batch(const vector<LocBin*>& loci);
+    int    write_header();
+    int    post_processing();
+    void   close();
+};
+
+class MapMakerExport: public Export {
+    const MetaPopInfo*_mpopi;
+    const MappingGenotypesProcessor *_gproc;
+    size_t _progeny_index;
+
+    string   _tmp_path;
+    ofstream _tmpfh;
+    ifstream _intmpfh;
+
+    map<string, string>              _marker_map;
+    map<string, map<string, string>> _genotype_map;
+
+ public:
+    MapMakerExport(MappingGenotypesProcessor *g) : _mpopi(NULL), _gproc(g) {}
+    MapMakerExport() : _mpopi(NULL) {}
+    int    open(const MetaPopInfo *mpopi);
+    int    write_batch(const vector<LocBin*>& loci);
+    int    write_header() { return 0; }
+    int    post_processing();
+    void   close();
+};
+
 /*
 int write_generic(map<int, CSLocus *> &, PopMap<CSLocus> *, bool);
-int write_vcf_haplotypes(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 int write_phase(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 int write_fastphase(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
-int write_plink(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
-int write_hzar(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
-int write_fullseq_phylip(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 */
 
 int find_datum_allele_depths(const Datum*, int, char, char, int &, int &);
 int tally_observed_haplotypes(const vector<char *> &, int, char &, char &);
-int tally_haplotype_freq(CSLocus *, Datum **, uint, int &, double &, string &);
 
 #endif // EXPORT_FORMATS_H
