@@ -36,6 +36,8 @@ const char *bspDI[]   = {"CGAT",              // AT/CGAT, BspDI
                          "ATCG"};
 const char *bstYI[]   = {"GATCC", "GATCT",    // R/GATCY, BstYI (also known as PsuI)
                          "GGATC", "AGATC"};
+const char *btgI[]    = {"CACGG", "CGCGG", "CATGG", "CGTGG", // C/CRYGG, BtgI
+                         "CCGTG", "CCGCG", "CCATG", "CCACG"};
 const char *cac8I[]    = {"AGC", "CGC", "GGC", "TGC", // GCN/NGC, Cac8I
                           "GCT", "GCG", "GCC", "GCA"};
 const char *claI[]    = {"CGAT",              // AT/CGAT, ClaI
@@ -62,6 +64,8 @@ const char *hindIII[] = {"AGCTT",             // A/AGCTT, HindIII
                          "TCGAA"};
 const char *hpaII[]   = {"CGG",               // C/CGG, HpaII
                          "CCG"};
+const char *hpyCH4IV[] = {"CGT",               // A/CGT, HpyCH4IV
+                          "ACG"};
 const char *kpnI[]    = {"GTACC",             // C/CATGG, KpnI
                          "GGTAC"};
 const char *mluCI[]   = {"AATT",              // AATT, MluCI
@@ -98,6 +102,10 @@ const char *nsiI[]    = {"TGCAT",             // ATGCA/T, NsiI
                          "ATGCA"};
 const char *nspI[]    = {"CATGA", "CATGG",    // R/CATGY, NspI
                          "GCATG", "ACATG"};
+const char *pacI[]    = {"ATTAA",             // AAT/TAATT, PacI
+                         "TTAAT"};
+const char *pspXI[]   = {"TCGAGC", "TCGAGG", "TCGAGT", // VC/TCGAGB, PspXI
+                         "GCTCGA", "CCTCGA", "ACTCGA"};
 const char *pstI[]    = {"TGCAG",             // CTGCA/G, PstI
                          "CTGCA"};
 const char *rsaI[]    = {"AC",                // GT/AC, RsaI
@@ -178,6 +186,10 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz["apaLI"]   = apaLI;   // G/TGCAC, ApaLI
     renz["hinP1I"]  = hinP1I;  // G/CGC, HinP1I
     renz["bbvCI"]   = bbvCI;
+    renz["btgI"]    = btgI;    // C/CRYGG, BtgI
+    renz["pacI"]    = pacI;    // AAT/TAATT, PacI
+    renz["pspXI"]   = pspXI;   // VC/TCGAGB, PspXI
+    renz["hpyCH4IV"] = hpyCH4IV; // A/CGT, HpyCH4IV
 
     renz_cnt["sbfI"]    = 1;
     renz_cnt["pstI"]    = 1;
@@ -231,7 +243,11 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_cnt["apaLI"]   = 1;
     renz_cnt["hinP1I"]  = 1;
     renz_cnt["bbvCI"]   = 1;
-
+    renz_cnt["btgI"]    = 4;
+    renz_cnt["pacI"]    = 1;
+    renz_cnt["pspXI"]   = 3;
+    renz_cnt["hpyCH4IV"] = 1;
+    
     renz_len["sbfI"]    = 6;
     renz_len["pstI"]    = 5;
     renz_len["notI"]    = 6;
@@ -284,6 +300,10 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_len["apaLI"]   = 5;
     renz_len["hinP1I"]  = 3;
     renz_len["bbvCI"]   = 5;
+    renz_len["btgI"]    = 5;
+    renz_len["pacI"]    = 5;
+    renz_len["pspXI"]   = 6;
+    renz_len["hpyCH4IV"] = 3;
 }
 
 void
